/*
* Copyright (c) 2013 Samsung Electronics Co., Ltd All Rights Reserved
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#ifndef __TIZEN_MULTIMEDIA_LEGACY_CAMERA_INTERNAL_H__
#define __TIZEN_MULTIMEDIA_LEGACY_CAMERA_INTERNAL_H__
#include <legacy_camera.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
  * @file camera_internal.h
  * @brief This file contains the Camera internal API for framework, related structures and enumerations.
  */

/**
 * @brief Set pid of client.
 * @ingroup CAPI_MEDIA_CAMERA_MUSED_MODULE
 * @param[in] camera The handle to the camera
 * @param[in] pid The pid of client
 *
 * @return @c 0 on success, otherwise a negative error value
 * @retval #CAMERA_ERROR_NONE Successful
 * @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
 * @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
 * @retval #CAMERA_ERROR_INVALID_STATE Invalid state
 * @pre The camera state must be #CAMERA_STATE_CREATED by legacy_camera_create().
 */
int legacy_camera_set_client_pid(camera_h camera, int pid);

/**
 * @brief Emit signal to notify some information.
 * @ingroup CAPI_MEDIA_CAMERA_MUSED_MODULE
 * @param[in] camera The handle to the camera
 * @param[in] object_name The name of signal object
 * @param[in] interface_name The name of signal interface
 * @param[in] signal_name The name of signal
 * @param[in] value The value of signal to emit
 */
void legacy_camera_emit_signal(camera_h camera, const char *object_name,
	const char *interface_name, const char *signal_name, int value);

/**
 * @brief Set gdbus connection created from outside.
 * @ingroup CAPI_MEDIA_CAMERA_MUSED_MODULE
 * @param[in] camera The handle to the camera
 * @param[in] gdbus_conn The connection of gdbus
 *
 * @return @c 0 on success, otherwise a negative error value
 * @retval #CAMERA_ERROR_NONE Successful
 * @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
 * @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
 * @retval #CAMERA_ERROR_INVALID_STATE Invalid state
 * @pre The camera state must be #CAMERA_STATE_CREATED by legacy_camera_create().
 */
int legacy_camera_set_gdbus_connection(camera_h camera, void *gdbud_connection);


#ifdef __cplusplus
}
#endif

#endif /* __TIZEN_MULTIMEDIA_LEGACY_CAMERA_INTERNAL_H__ */
