/*
* Copyright (c) 2011 Samsung Electronics Co., Ltd All Rights Reserved
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#ifndef __CAMERA_MSG_PRIVATE_H__
#define __CAMERA_MSG_PRIVATE_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <muse_core.h>

/**
 * @file muse_camera_msg.h
 * @brief This file contains the muse_camera message APIs, related structures, defines and macros.
 */

/**
 * @brief Definition for the handle parameter.
 */
#define PARAM_HANDLE        "handle"

/**
 * @brief Definition for the ret parameter.
 */
#define PARAM_RET           "ret"

/**
 * @brief Definition for the get_type parameter.
 */
#define PARAM_GET_TYPE      "get_type"

/**
 * @brief Definition for the get_index parameter.
 */
#define PARAM_GET_INDEX     "get_index"

/**
 * @brief Definition for the event parameter.
 */
#define PARAM_EVENT         "event"

/**
 * @brief Definition for the api class parameter.
 */
#define PARAM_API_CLASS     "api_class"

/**
 * @brief Definition for the event class parameter.
 */
#define PARAM_EVENT_CLASS   "event_class"

/**
 * @brief Definition for the error parameter.
 */
#define PARAM_ERROR         "error"

/**
 * @brief Definition for the tbm key parameter.
 */
#define PARAM_TBM_KEY       "t_key"

/**
 * @brief Definition for the display mode parameter.
 */
#define PARAM_DISPLAY_MODE  "display_mode"

/**
 * @brief Definition for the device type parameter.
 */
#define PARAM_DEVICE_TYPE   "device_type"

/**
 * @brief Definition for the INTEGER type.
 */
typedef int32_t INT;

/**
 * @brief Definition for the 64 bit INTEGER type.
 */
typedef int64_t INT64;

/**
 * @brief Definition for the 64 bit integer pointer type.
 */
typedef intptr_t POINTER;

/**
 * @brief Definition for the 64 bit DOUBLE type.
 */
typedef double DOUBLE;

/**
 * @brief Definition for the 64 bit STRING type.
 */
typedef const char* STRING;


/**
 * @brief Query the specific value from the input message via ipc.
 * @param[in] param The key to query, the variable name should be matched to the message's one.
 * @param[out] buf The string of message buffer.
 */
#define muse_camera_msg_get(param, buf) \
	muse_core_msg_deserialize(#param, buf, NULL, NULL, MUSE_TYPE_ANY, &param)

/**
 * @brief Query the specific string type value from the input message via ipc.
 * @param[in] param The key to query, the variable name should be matched to the message's one.
 * @param[out] buf The string of message buffer.
 */
#define muse_camera_msg_get_string(param, buf) \
	muse_core_msg_deserialize(#param, buf, NULL, NULL, MUSE_TYPE_STRING, param)

/**
 * @brief Query the specific array type value from the input message via ipc.
 * @param[in] param The key to query, the variable name should be matched to the message's one.
 * @param[out] buf The string of message buffer.
 */
#define muse_camera_msg_get_array(param, buf) \
	muse_core_msg_deserialize(#param, buf, NULL, NULL, MUSE_TYPE_ARRAY, param)

/**
 * @brief Query the specific pointer type value from the input message via ipc.
 * @param[in] param The key to query, the variable name should be matched to the message's one.
 * @param[out] buf The string of message buffer.
 */
#define muse_camera_msg_get_pointer(param, buf) \
	muse_core_msg_deserialize(#param, buf, NULL, NULL, MUSE_TYPE_POINTER, &param)

#ifdef __cplusplus
}
#endif

#endif /*__CAMERA_MSG_PRIVATE_H__*/
